@@ -53,13 +53,13 @@ PLSc <- function(seminr_model) {
   rSquared <- seminr_model$rSquared
   construct_scores <- seminr_model$construct_scores
 
-  # Calculate rhoA for adjustments and adjust the correlation matrix
-  rho <- rhoA(seminr_model)
+  # Calculate rho_A for adjustments and adjust the correlation matrix
+  rho <- rho_A(seminr_model)
   adjustment <- sqrt(rho %*% t(rho))
   diag(adjustment) <- 1
   adj_construct_score_cors <- stats::cor(seminr_model$construct_scores) / adjustment
 
-  # iterate over endogenous latents and adjust path coefficients and R-squared
+  # iterate over endogenous constructs and adjust path coefficients and R-squared
   for (i in unique(smMatrix[,"target"]))  {
 
     #Indentify the exogenous variables
@@ -78,13 +78,13 @@ PLSc <- function(seminr_model) {
   #calculate insample metrics
   rSquared <- calc_insample(seminr_model$data, construct_scores, smMatrix, unique(smMatrix[,"target"]),adj_construct_score_cors)
 
-  # get all common-factor latents (Mode A Consistent) in a vector
-  reflective <- unique(mmMatrix[mmMatrix[,"type"]=="C", "latent"])
+  # get all common-factor constructs (Mode A Consistent) in a vector
+  reflective <- unique(mmMatrix[mmMatrix[,"type"]=="C", "construct"])
 
   # function to adjust the loadings of a common-factor
   adjust_loadings <- function(i) {
-    w <- as.matrix(seminr_model$outer_weights[mmMatrix[mmMatrix[,"latent"]==i,"measurement"],i])
-    loadings[mmMatrix[mmMatrix[,"latent"]==i,"measurement"],i] <- w %*% (sqrt(rho[i,]) / t(w) %*% w )
+    w <- as.matrix(seminr_model$outer_weights[mmMatrix[mmMatrix[,"construct"]==i,"measurement"],i])
+    loadings[mmMatrix[mmMatrix[,"construct"]==i,"measurement"],i] <- w %*% (sqrt(rho[i,]) / t(w) %*% w )
     loadings[,i]
   }
 
